@@ -9,6 +9,6 @@ from .negative_keywords import NegativeKeywords
 from .negative_product_targeting import NegativeProductTargeting
 from .product_ads import ProductAds, ProductAdsV3
 from .product_targeting import ProductTargeting, ProductTargetingV3
-from .reports import Reports, Reporting
+from .reports import Reports
 from .snapshots import Snapshots
 from .suggested_keywords import SuggestedKeywords
